; NAME:                barplot_5_idl
;
; DESCRIPTION:         displays a bar plot
;
; EXECUTION COMMAND:
;                      IDL> .compile barplot_5_idl
;                      IDL> barplot_5_idl
;
; INPUTS:              random input data
;
; OUTPUTS:             PDF file: plot.pdf
;
; NOTES:               change the input data. 
;                              change the output PDF name.
;  
; AUTHOR:              Leonardo UBEDA
;                                Space Telescope Science Institute, USA 
; 
; REVISION HISTORY:
;                      Written by Leonardo UBEDA, JUN 2013. 
;
;

 

; ------------------------ idl code begins here
pro barplot_5_idl

; define page size (in cm)
page_height = 27.94
page_width = 21.59

; define plot position and size (in cm)
plot_left = 3.
plot_bottom =15
xsize = 8 
ysize = 8. 


; use postscript output 
set_plot, 'ps'
; name the output file 
psname = 'plot.ps'

; open the postscript file
device, filename = psname, $
xsize = page_width, $
ysize = page_height, $
xoffset = 0, $
yoffset = 0, $
scale_factor = 1.0, $
/portrait 

; create data and labels for the bar plot.
   data = [1, 0.85, 0.0, 0.6, 0.4, 0.0, 0.8, 0.95]
   labels = [ 'exp 1',  'exp 2', 'exp 3' ]   

; set up colors for the bar plot.
cgloadct, 33, clip=[10,245]
colors = ['blu7','blu5', 'white', 'blu7','blu5', 'white', 'blu7','blu5']

; draw the bar plot  
cgbarplot, data, $
charsize = 1.2, $
colors = colors, $
barcoords = xlocs, $
baroffset = 0.4, $
barspace = 0, $
baserange = 0.9, $
xstyle = 1, ystyle = 1, $
ytitle = 'Normalised Frequency', $
position = [plot_left / page_width, plot_bottom / page_height, (plot_left + xsize) / page_width, (plot_bottom + ysize) / page_height] 
    
; metallicity symbol
;; solar_met = 'Z!10!d!z(2609)!x!n' + cgsymbol('sun')
 solar_met = 'Z' + cgsymbol('sun')
 
; display x axis labels
xyouts, [xlocs[0],  xlocs[3],  xlocs[6]] + 0.3, [-0.1,  -0.1,  -0.1] , [ '0.4 ' + solar_met,  solar_met,  '2.5 ' + solar_met],  charsize = 1.2, orientation = 0


; display x axis title
xyouts, [xlocs[3]] - 0.1, [-0.2] , 'Metallicity', charsize = 1.2 , orientation = 0
 


; display lables 
xyouts, xlocs[3] + 0.1, [1.1] , 'inner disk',      charsize= 1.2 , orientation = 90, alignment = 1
xyouts, xlocs[4] + 0.1, [1.1] , 'outer galaxy', charsize= 1.2 , orientation = 90, alignment = 1



;display vertical lines
oplot, xlocs[3]*[1,1], [0.62, 0.78], thick = 3
oplot, xlocs[4]*[1,1], [0.42, 0.70], thick = 3
 
; close postscript file
device,/close

; create a PDF file
cgps2pdf, psname, /delete_ps

end
; ------------------------ idl code ends here
